@@ -32,8 +32,13 @@ use secrecy::ExposeSecret;
 use webpki::anchor_from_trusted_cert;
 use zenoh_config::Config as ZenohConfig;
 use zenoh_link_commons::{
-    tcp::TcpSocketConfig, tls::WebPkiVerifierAnyServerName, ConfigurationInspector, BIND_INTERFACE,
-    BIND_SOCKET, TCP_SO_RCV_BUF, TCP_SO_SND_BUF,
+    parse_dscp,
+    tcp::TcpSocketConfig,
+    tls::{
+        config::{self, *},
+        WebPkiVerifierAnyServerName,
+    },
+    ConfigurationInspector, BIND_INTERFACE, BIND_SOCKET, TCP_SO_RCV_BUF, TCP_SO_SND_BUF,
 };
 use zenoh_protocol::core::{
     endpoint::{Address, Config},
@@ -41,8 +46,6 @@ use zenoh_protocol::core::{
 };
 use zenoh_result::{bail, zerror, ZError, ZResult};
 
-use crate::config::{self, *};
-
 #[derive(Default, Clone, Copy, Debug)]
 pub struct TlsConfigurator;
 
@@ -77,7 +80,7 @@ impl ConfigurationInspector<ZenohConfig> for TlsConfigurator {
             }
             (None, Some(server_private_key)) => {
                 ps.push((
-                    TLS_LISTEN_PRIVATE_KEY_BASE_64,
+                    TLS_LISTEN_PRIVATE_KEY_BASE64,
                     server_private_key.expose_secret(),
                 ));
             }
@@ -285,6 +288,7 @@ impl<'a> TlsServerConfig<'a> {
                 tcp_rx_buffer_size,
                 config.get(BIND_INTERFACE),
                 bind_socket,
+                parse_dscp(config)?,
             ),
         })
     }
@@ -294,7 +298,7 @@ impl<'a> TlsServerConfig<'a> {
             config,
             TLS_LISTEN_PRIVATE_KEY_RAW,
             TLS_LISTEN_PRIVATE_KEY_FILE,
-            TLS_LISTEN_PRIVATE_KEY_BASE_64,
+            TLS_LISTEN_PRIVATE_KEY_BASE64,
         )
         .await
     }
@@ -443,7 +447,6 @@ impl<'a> TlsClientConfig<'a> {
                     .map_err(|_| zerror!("Unknown TCP write buffer size argument: {}", size))?,
             );
         };
-
         let mut bind_socket = None;
         if let Some(bind_socket_str) = config.get(BIND_SOCKET) {
             bind_socket = Some(get_tls_addr(&Address::from(bind_socket_str)).await?);
@@ -457,6 +460,7 @@ impl<'a> TlsClientConfig<'a> {
                 tcp_rx_buffer_size,
                 config.get(BIND_INTERFACE),
                 bind_socket,
+                parse_dscp(config)?,
             ),
         })
     }
